@@ -1,9 +1,10 @@
+import six
+
 import numpy as np
 
 from astropy.io import fits
 from astropy.io.fits import PrimaryHDU, ImageHDU, CompImageHDU, Header, HDUList
 from astropy.wcs import WCS
-from astropy.extern import six
 
 
 def parse_input_data(input_data, hdu_in=None):
@@ -44,7 +45,15 @@ def parse_output_projection(output_projection, shape_out=None):
         wcs_out = output_projection
         if shape_out is None:
             raise ValueError("Need to specify shape when specifying output_projection as WCS object")
+    elif isinstance(output_projection, six.string_types):
+        hdu_list = fits.open(output_projection)
+        shape_out = hdu_list[0].data.shape
+        header = hdu_list[0].header
+        wcs_out = WCS(header)
+        hdu_list.close()
     else:
-        raise TypeError('output_projection should either be a Header or a WCS object')
+        raise TypeError('output_projection should either be a Header, a WCS object, or a filename')
 
+    if len(shape_out) == 0:
+        raise ValueError("The shape of the output image should not be an empty tuple")
     return wcs_out, shape_out
